@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2022-11-12
+# Release 2022-11-25
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.6.2
+MAKERESOLVEDEB_VERSION=1.6.3
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -18,8 +18,7 @@ check_command() {
 
 copy_object() {
     if [[ -e "$1" ]] ; then
-	if ! cp -rp "$1" "$2";
-	then
+	if ! cp -rp "$1" "$2"; then
 	    ERRORS=$((ERRORS+1))
 	fi
     else
@@ -36,12 +35,20 @@ assert_object() {
 }
 
 link_object() {
-    ln -s "$1" "$2"
+    if [[ -e "$2" ]] ; then
+	echo "[ERROR: LINK ALREADY EXISTS] $2"
+	ERRORS=$((ERRORS+1))
+    else
+	if ! ln -s "$1" "$2"; then
+	    echo "[ERROR: UNABLE TO CREATE LINK] $2 -> $1"
+	    ERRORS=$((ERRORS+1))
+	fi
+    fi
 }
 
 create_directory() {
     if [[ -e "$1" ]] ; then
-	echo "[ERROR: DIRECTORY EXISTS] $1"
+	echo "[ERROR: DIRECTORY ALREADY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
 	mkdir -p "$1"
@@ -505,18 +512,21 @@ installer_extract_native() {
     # Extract archive
     echo "Extracting archive"
     createf_directory ${UNPACK_DIR}
-    UNPACK_DIR_ABS=$(cd "${UNPACK_DIR}"; pwd)
     chmod a+x ${INSTALLER_ARCHIVE}
     if [[ ! -x ${INSTALLER_ARCHIVE} ]];
     then
 	echo "[ERROR] DaVinci Resolve installer archive is not executable"
 	exit 1
     fi
-    NUMEXTRACT=$(SKIP_PACKAGE_CHECK=1 ./${INSTALLER_ARCHIVE} -i -y -n -C ${UNPACK_DIR_ABS} | grep "^Copied " -c)
+    link_object ${UNPACK_DIR} ./squashfs-root
+    EXTRACT_OUT=$(./${INSTALLER_ARCHIVE} --appimage-extract 2>&1)
+    rm -f ./squashfs-root
+    NUMEXTRACT=$(echo "${EXTRACT_OUT}" | grep "^squashfs-root/" -c)
     echo "Found ${NUMEXTRACT} objects"
     if [[ -z "$(ls -A ${UNPACK_DIR})" ]];
     then
 	echo "[ERROR] Failed to extract DaVinci Resolve installer archive"
+	echo "${EXTRACT_OUT}" | tail
 	remove_directory ${UNPACK_DIR}
 	exit 1
     fi
@@ -643,7 +653,7 @@ case $RESOLVE_VERSION in
 	;;
     16.*)
 	echo "Using Resolve 16 conversion process"
-	installer_extract_native
+	installer_extract_xorriso
 	process_16
 	process_braw
 	process_udev
